// This file was generated by qtwaylandscanner
// source file is /scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build-136_VersalFullPrime/build/tmp/work/cortexa72-cortexa53-xilinx-linux/qtwayland/5.15.4+gitAUTOINC+f1e6c8764d-r0/git/src/extensions/qt-dmabuf-server-buffer.xml

#ifndef QT_WAYLAND_QT_DMABUF_SERVER_BUFFER
#define QT_WAYLAND_QT_DMABUF_SERVER_BUFFER

#include "wayland-qt-dmabuf-server-buffer-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")

namespace QtWayland {
    class  qt_dmabuf_server_buffer
    {
    public:
        qt_dmabuf_server_buffer(struct ::wl_registry *registry, int id, int version);
        qt_dmabuf_server_buffer(struct ::qt_dmabuf_server_buffer *object);
        qt_dmabuf_server_buffer();

        virtual ~qt_dmabuf_server_buffer();

        void init(struct ::wl_registry *registry, int id, int version);
        void init(struct ::qt_dmabuf_server_buffer *object);

        struct ::qt_dmabuf_server_buffer *object() { return m_qt_dmabuf_server_buffer; }
        const struct ::qt_dmabuf_server_buffer *object() const { return m_qt_dmabuf_server_buffer; }
        static qt_dmabuf_server_buffer *fromObject(struct ::qt_dmabuf_server_buffer *object);

        bool isInitialized() const;

        static const struct ::wl_interface *interface();

    protected:
        virtual void dmabuf_server_buffer_server_buffer_created(struct ::qt_server_buffer *id, int32_t fd, int32_t width, int32_t height, int32_t stride, int32_t offset, int32_t fourcc_format);

    private:
        void init_listener();
        static const struct qt_dmabuf_server_buffer_listener m_qt_dmabuf_server_buffer_listener;
        static void handle_server_buffer_created(
            void *data,
            struct ::qt_dmabuf_server_buffer *object,
            struct ::qt_server_buffer *id,
            int32_t fd,
            int32_t width,
            int32_t height,
            int32_t stride,
            int32_t offset,
            int32_t fourcc_format);
        struct ::qt_dmabuf_server_buffer *m_qt_dmabuf_server_buffer;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
